@@ -1,5 +1,5 @@
 
-"pmixed" <- 
+".pmixed" <- 
   function(value, parms, df)
 {
   if(ncol(parms$var)==1) parms$var <- as.vector(parms$var)
@@ -38,7 +38,7 @@
 }
 
 
-"model.glm.check.aux" <-
+".model.glm.check.aux" <-
   function(model, fct)
 {
   if(class(model) != "model.geoRglm"){
@@ -46,7 +46,7 @@
       stop(paste(fct,": the argument model only takes a list or an output of the function model.glm.control"))
     else{
       model.names <- c("trend.d", "trend.l", "cov.model", "kappa", "aniso.pars", "lambda")
-      model <- object.match.names(model,model.names)
+      model <- .object.match.names(model,model.names)
       if(is.null(model$trend.d)) model$trend.d <- "cte"  
       if(is.null(model$trend.l)) model$trend.l <- "cte"  
       if(is.null(model$cov.model)) model$cov.model <- "matern"  
@@ -67,7 +67,7 @@
 }
 
 
-"multgauss" <- 
+".multgauss" <- 
   function(cov)
 {
   if(is.R())
@@ -91,7 +91,7 @@
   return(res)
 }
 
-"mcmc.check.aux" <-
+".mcmc.check.aux" <-
   function(mcmc.input, fct)
 {
   if(class(mcmc.input) != "mcmc.geoRglm"){
@@ -99,7 +99,7 @@
       stop(paste(fct,": the argument mcmc.input only takes a list or an output of the function mcmc.control"))
     else{
       mcmc.input.names <- c("S.scale", "Htrunc", "S.start", "burn.in", "thin", "n.iter", "phi.start", "phi.scale")  
-      mcmc.input <- object.match.names(mcmc.input,mcmc.input.names)
+      mcmc.input <- .object.match.names(mcmc.input,mcmc.input.names)
       if(fct=="pois.krige.bayes" | fct=="binom.krige.bayes"){
         if(is.null(mcmc.input$phi.start)) mcmc.input$phi.start <- "default"
       }
@@ -112,7 +112,7 @@
 }
 
 
-"BC.inv" <- 
+".BC.inv" <- 
   function(z,lambda)
 {
   return(BCtransform(z, lambda = lambda, inverse=TRUE)$data)
@@ -163,7 +163,7 @@
 }
 
 
-"output.glm.check.aux" <-
+".output.glm.check.aux" <-
   function(output, fct)
 {
   if(class(output) != "output.geoRglm"){
@@ -171,7 +171,7 @@
       stop(paste(fct,": the argument output only takes a list or an output of the function output.glm.control"))
     else{
       output.names <- c("sim.posterior","sim.predict", "keep.mcmc.sim","quantile","threshold","inference","messages.screen")
-      output <- object.match.names(output,output.names)
+      output <- .object.match.names(output,output.names)
       if(is.null(output$sim.predict)) output$sim.predict <- FALSE
       if(is.null(output$messages.screen)) output$messages.screen <- TRUE        
       output <- output.glm.control(sim.posterior = output$sim.posterior,
@@ -185,7 +185,7 @@
 }
 
 
-"object.match.names" <- function(obj,names)
+".object.match.names" <- function(obj,names)
 {
   obj.names <- names(obj)
   new.obj <- list()
